@@ -20,6 +20,7 @@
  * 
  */
 
+#include <math.h>
 #include <pds/pdsrautils.h>
 #include <pds/pdsmatrix.h>
 
@@ -1770,6 +1771,163 @@ PdsMatrix *pds_matrix_inverse_matrix_new(const PdsMatrix *Matrix)
 }
 
 
+/** \fn int pds_matrix_is_equal (PdsMatrix *M1,PdsMatrix *M2)
+ *  \brief Compara dos matrices.
+ *  \param[in] M1 La matriz a comparar com M2.
+ *  \param[in] M2 La matriz a comparar com M1.
+ *  \return Retorna TRUE si las matrices son iguales, caso contrario retorna FALSE. 
+ *  \ingroup PdsMatrixGroup
+ */
+int pds_matrix_is_equal (PdsMatrix *M1,PdsMatrix *M2)
+{
+	int i,j;
+	if ((M1==NULL)|| (M2==NULL))	return FALSE;
+	if ((M1->Nlin!=M2->Nlin)|| (M1->Ncol!=M2->Ncol))	return FALSE;
+	
+	for(i=0;i<M1->Nlin;i++)
+	for(j=0;j<M1->Ncol;j++)
+	{
+		if(M1->M[i][j]!=M2->M[i][j])	return FALSE;
+	}
+	
+	return TRUE;
+}
+
+/** \fn int pds_matrix_is_quasiequal (PdsMatrix *M1,PdsMatrix *M2,double u)
+ *  \brief Compara dos matrices, y verifica si la diferencia absoluta de cada 
+ *  elemento es menor que un umbral u.
+ *  \param[in] M1 La matriz a comparar com M2.
+ *  \param[in] M2 La matriz a comparar com M1.
+ *  \param[in] u Es el umbrarl a testar.
+ *  \return Retorna TRUE si las matrices son quasi iguales 
+ *  (diferencia de elementos menoro igual a u), caso contrario retorna FALSE. 
+ *  \ingroup PdsMatrixGroup
+ */
+int pds_matrix_is_quasiequal (PdsMatrix *M1,PdsMatrix *M2,double u)
+{
+	int i,j;
+	if ((M1==NULL)|| (M2==NULL))	return FALSE;
+	if ((M1->Nlin!=M2->Nlin)|| (M1->Ncol!=M2->Ncol))	return FALSE;
+	
+	for(i=0;i<M1->Nlin;i++)
+	for(j=0;j<M1->Ncol;j++)
+	{
+		if (fabs(M1->M[i][j]-M2->M[i][j])>u)	return FALSE;
+	}
+	
+	return TRUE;
+}
+
+/** \fn int pds_matrix_is_diagonal (PdsMatrix *M1)
+ *  \brief Verifica si una matriz es diagonal.
+ *
+ *  Una matriz es diagonal cuando sus elementos exteriores a la diagonal 
+ *  principal son nulos. Una matriz nula (llena de ceros) tambien es diagonal.
+ *
+ *  \param[in] M1 La matriz a verificar su diagonalidad.
+ *  \return Retorna TRUE si las matriz es diagonal, caso contrario retorna FALSE. 
+ *  Tambien retorna FALSE si la matriz no es cuadrada.
+ *  \ingroup PdsMatrixGroup
+ */
+int pds_matrix_is_diagonal (PdsMatrix *M1)
+{
+	int i,j;
+	if (M1==NULL)	return FALSE;
+	if (M1->Nlin!=M1->Ncol)	return FALSE;	
+	
+	for(i=0;i<M1->Nlin;i++)
+	for(j=0;j<M1->Ncol;j++)
+	{
+		if(i!=j)
+		if(M1->M[i][j]!=0)	return FALSE;
+	}
+	
+	return TRUE;
+}
+
+/** \fn int pds_matrix_is_quasidiagonal (PdsMatrix *M1,double u)
+ *  \brief Verifica si una matriz es casi diagonal. Usa un umbral u, qualquier 
+ *  valor menor o igual que u es considerado cero.
+ *
+ *  Una matriz es diagonal cuando sus elementos exteriores a la diagonal 
+ *  principal son nulos. Una matriz nula (llena de ceros) tambien es diagonal.
+ *
+ *  \param[in] M1 La matriz a verificar su diagonalidad.
+ *  \param[in] u Es el umbral bajo el cual todo lo demas se considera cero.
+ *  \return Retorna TRUE si las matriz es diagonal, caso contrario retorna FALSE.
+ *  Tambien retorna FALSE si la matriz no es cuadrada. 
+ *  \ingroup PdsMatrixGroup
+ */
+int pds_matrix_is_quasidiagonal (PdsMatrix *M1,double u)
+{
+	int i,j;
+	if (M1==NULL)	return FALSE;
+	if (M1->Nlin!=M1->Ncol)	return FALSE;	
+	
+	for(i=0;i<M1->Nlin;i++)
+	for(j=0;j<M1->Ncol;j++)
+	{
+		if(i!=j)
+		if(M1->M[i][j]>u)	return FALSE;
+	}
+	
+	return TRUE;
+}
+
+
+/** \fn int pds_matrix_is_symetric (PdsMatrix *M1)
+ *  \brief Verifica si una matriz es simétrica.
+ *
+ *  Una matriz es simétrica si coincide con su transpuesta.
+ *
+ *  \param[in] M1 La matriz a verificar su simetria.
+ *  \return Retorna TRUE si las matriz es simetrica, caso contrario retorna FALSE. 
+ *  Tambien retorna FALSE si la matriz no es cuadrada.
+ *  \ingroup PdsMatrixGroup
+ */
+int pds_matrix_is_symetric (PdsMatrix *M1)
+{
+	int i,j;
+	if (M1==NULL)	return FALSE;
+	if (M1->Nlin!=M1->Ncol)	return FALSE;
+	
+	for(i=0;i<M1->Nlin;i++)
+	for(j=i+1;j<M1->Ncol;j++)
+	{
+		if(M1->M[i][j]!=M1->M[j][i])	return FALSE;
+	}
+	
+	return TRUE;
+}
+
+
+/** \fn int pds_matrix_is_antisymetric (PdsMatrix *M1)
+ *  \brief Verifica si una matriz es anti simétrica.
+ *
+ *  Una matriz es anti simétrica cuando el opuesto de esta  coincide con su transpuesta.
+ *  De esto se deduce que los elementos de la diagonal son nulos.
+ *  <br><b>M1^t=-M1</b>.
+ *
+ *  \param[in] M1 La matriz a verificar su anti simetria.
+ *  \return Retorna TRUE si las matriz es anti simetrica, caso contrario retorna FALSE. 
+ *  Tambien retorna FALSE si la matriz no es cuadrada.
+ *  \ingroup PdsMatrixGroup
+ */
+int pds_matrix_is_antisymetric (PdsMatrix *M1)
+{
+	int i,j;
+	if (M1==NULL)	return FALSE;
+	if (M1->Nlin!=M1->Ncol)	return FALSE;
+	
+	for(i=0;i<M1->Nlin;i++)
+	for(j=i;j<M1->Ncol;j++)
+	{
+		if(M1->M[i][j]!=-M1->M[j][i])	return FALSE;
+	}
+	
+	return TRUE;
+}
+
 /** \fn void pds_matrix_free(PdsMatrix *Matrix)
  *  \brief Libera una matriz de tipo puntero PdsMatrix.
  *  \param[in,out] Matrix la matriz a liberar.
