@@ -49,31 +49,33 @@ extern "C" {
 	#define FALSE 0
 #endif
 
-/** \defgroup PdsVectorGroup Funciones del módulo PdsVector.
+/** \defgroup PdsVectorGroup Módulo PdsVector.
  *  \brief Funciones que trabajan con vectores.
  *  
  *  <br>Estas funciones trabajan con un vector de la forma.<br>
- *  \image html vector.png "Vector de Nel elementos"
- *  \b Nel es el número de elementos.
+ *  <center>
+ *  \image html vector.png "Vector de \b Nel elementos"
+ *  </center>
  * @{
  */
 
-/*! \def _VECSETVAL(Vector,X,m)
- *  Es equivalente a Vector(X)=m.
+/*! \def _VECSETVAL(Vector,id,Val)
+ *  Es equivalente a Vector{id}=Val.
  *  \ingroup PdsVectorGroup
 */
-#define _VECSETVAL(Vector,X,m) pds_vector_set_value(Vector,X,m)
+#define _VECSETVAL(Vector,id,Val) pds_vector_set_value(Vector,id,Val)
 
 /*! \struct PdsVector
- *  \brief La estructura tipo  PdsVector .
- *  Esta estructura genera una matriz de Nel elementos.
- *  Para usar incluir pds/pdsvector.h.
+ *  \brief Estructura de tipo  PdsVector .
+ *
+ *  Esta estructura genera una matriz de \b Nel elementos.
+ *  Para usar incluir la cabecera pds/pdsvector.h.
  *  \ingroup PdsVectorGroup
  *  \author Fernando Pujaico Rivera
  */
 typedef struct 
 {
-	/*! Un arreglo de Nel elementos. */
+	/*! Un arreglo unidimencional de \b Nel elementos. */
 	PdsRaReal *V;
 	/*! Número de elementos. */
 	PdsRaNatural Nel;
@@ -89,8 +91,9 @@ PdsVector *pds_vector_new(PdsRaNatural Nel);
 
 
 /** \fn PdsVector *pds_vector_new_vector(const PdsVector *VecSrc)
- *  \brief Crea un vector de tipo PdsVector usando como fuente el vector VecSrc.
- *  \param[in] VecSrc Es el vector imagen que se usará como fuente.
+ *  \brief Crea un vector de tipo PdsVector e inicia sus valores con el contenido
+ *  de el vector VecSrc.
+ *  \param[in] VecSrc Es el vector que se usará como fuente.
  *  \return Un puntero al vector de tipo PdsVector.
  *  \ingroup PdsVectorGroup
  */
@@ -99,7 +102,7 @@ PdsVector *pds_vector_new_vector(const PdsVector *VecSrc);
 
 /** \fn PdsVector *pds_vector_new_load_data(const char* datafile)
  *  \brief Crea un nuevo vector e inicia los datos con los elementos del archivo
- *  datafile.
+ *  \b datafile.
  *  Usa TAB o un salto de linea como delimitador de elemento.
  *  \param[in] datafile Nombre del archivo de donde se cargará los datos iniciales
  *  del vector.
@@ -112,9 +115,10 @@ PdsVector *pds_vector_new_load_data(const char* datafile);
 
 /** \fn PdsVector *pds_vector_new_load_data_line(const char* datafile,PdsRaNatural line)
  *  \brief Crea un nuevo vector e inicia los datos con los elementos de la linea
- *  line del archivo datafile.
+ *  \b line del archivo \b datafile.
  *  Usa TAB como delimitador de elemento y un salto de linea como delimitador de linea.
- *  Si se pide una linea inexistente la funcion retorna NULL
+ *  La primera linea es \b line=0 .
+ *  Si se pide una linea inexistente la funcion retorna NULL.
  *  \param[in] datafile Nombre del archivo de donde se cargará los datos iniciales
  *  del vector.
  *  \param[in] line Número de linea que se cargará, line inicia en cero. 
@@ -127,8 +131,9 @@ PdsVector *pds_vector_new_load_data_line(const char* datafile,PdsRaNatural line)
 
 /** \fn PdsVector *pds_vector_new_load_data_col(const char* datafile,PdsRaNatural col)
  *  \brief Crea un nuevo vector e inicia los datos con los elementos de la columna
- *  col del archivo datafile.
+ *  \b col del archivo \b datafile.
  *  Usa TAB como delimitador de columna y un salto de linea como delimitador de linea.
+ *  La primera columna es \b col=0 .
  *  Si se pide una linea inexistente la función retorna NULL
  *  \param[in] datafile Nombre del archivo de donde se cargará los datos iniciales
  *  del vector.
@@ -141,9 +146,9 @@ PdsVector *pds_vector_new_load_data_col(const char* datafile,PdsRaNatural col);
 
 
 /** \fn int pds_vector_init_value(PdsVector *Vector,PdsRaReal Val)
- *  \brief Inicia el vector de tipo puntero PdsVector. <br><b>Vector=Val</b>.
- *  \param[in,out] Vector El vector a iniciar.
- *  \param[in] Val Es el valor inicial de los elementos.
+ *  \brief Inicia el vector \b Vector de tipo PdsVector *. <br><b>Vector{:}=Val</b>.
+ *  \param[in,out] Vector El vector a inicializar.
+ *  \param[in] Val Es el valor de inicialización de los elementos.
  *  \return TRUE si todo fue bien o FALSE si no.
  *  \ingroup PdsVectorGroup
  */
@@ -151,8 +156,8 @@ int pds_vector_init_value(PdsVector *Vector,PdsRaReal Val);
 
 
 /** \fn int pds_vector_init_vector(PdsVector *Vector,const PdsVector *VecSrc)
- *  \brief Inicia el vector de tipo puntero PdsVector con otro vector.
- *  Si los tamaños son diferentes intersecta los tamaños y hace la copia en la
+ *  \brief Se copia el contenido del vector \b VecSrc a el vector \b Vector.
+ *  Si los tamaños son diferentes se intersectan los tamaños y se hace la copia en la
  *  intersección solamente. <br><b>Vector=VecSrc</b>.
  *  \param[in,out] Vector Es el vector a iniciar.
  *  \param[in] VecSrc Es el vector fuente de la copia.
@@ -163,7 +168,7 @@ int pds_vector_init_vector(PdsVector *Vector,const PdsVector *VecSrc);
 
 
 /** \fn int pds_vector_add_vector(PdsVector *Vector,const PdsVector *VecSrc)
- *  \brief Suma al vector de tipo puntero PdsVector con otro vector y lo copia en Vector.
+ *  \brief Suma al vector \b Vector el vector \b VecSrc, el resultado es copiado a \b Vector.
  *  Si los tamaños son diferentes intersecta los tamaños y hace la copia en la
  *  intersección solamente. <br><b>Vector=Vector+VecSrc</b>.
  *  \param[in,out] Vector Es el vector de destino y operando.
@@ -175,8 +180,8 @@ int pds_vector_add_vector(PdsVector *Vector,const PdsVector *VecSrc);
 
 
 /** \fn int pds_vector_add_factor_vector(PdsVector *Vector,PdsRaReal Alpha,const PdsVector *VecSrc)
- *  \brief Suma al vector de tipo puntero PdsVector con otro vector con unf actor 
- *  y lo copia en Vector. Si los tamaños son diferentes intersecta los tamaños y 
+ *  \brief Suma al vector \b Vector el vector \b Alpha*VecSrc, el resultado es copiado a \b Vector.
+ *  Si los tamaños son diferentes se intersectan los tamaños y se
  *  hace la copia en la intersección solamente. <br><b>Vector=Vector+Alpha*VecSrc</b>.
  *  \param[in,out] Vector Es el vector de destino y operando.
  *  \param[in] Alpha Factor que multiplica al operando.
@@ -188,9 +193,9 @@ int pds_vector_add_factor_vector(PdsVector *Vector,PdsRaReal Alpha,const PdsVect
 
 
 /** \fn int pds_vector_add_value(PdsVector *Vector,PdsRaReal Val)
- *  \brief Suma al vector de tipo puntero PdsVector el valor Val. <br><b>Vector=Vector+Val</b>.
- *  \param[in,out] Vector El vector a sumar.
- *  \param[in] Val Es el valor inicial de los elementos.
+ *  \brief Suma al vector \b Vector el valor \b Val y lo carga en \b Vector. <br><b>Vector{:}=Vector{:}+Val</b>.
+ *  \param[in,out] Vector Es el vector a sumar.
+ *  \param[in] Val Es el valor a acumular.
  *  \return TRUE si todo fue bien o FALSE si no.
  *  \ingroup PdsVectorGroup
  */
@@ -210,7 +215,8 @@ int pds_vector_sub_vector(PdsVector *Vector,const PdsVector *VecSrc);
 
 
 /** \fn int pds_vector_mul_vector_elements(PdsVector *Vector,const PdsVector *VecSrc)
- *  \brief Multiplica al vector de tipo puntero PdsVector con otro vector y lo copia en Vector.
+ *  \brief Multiplica elemento a elemento el vector \b Vector con el vector 
+ *  \b VecSrc, el resultado es cargado a \b Vector.
  *  Si los tamaños son diferentes intersecta los tamaños y hace la copia en la
  *  intersección solamente. <br><b>Vector=Vector.VecSrc</b>.
  *  \param[in,out] Vector Es el vector de destino y operando.
@@ -222,8 +228,8 @@ int pds_vector_mul_vector_elements(PdsVector *Vector,const PdsVector *VecSrc);
 
 
 /** \fn int pds_vector_mul_value(PdsVector *Vector,PdsRaReal Val)
- *  \brief Multiplica al vector de tipo puntero PdsVector por un escalar. <br><b>Vector=Val*Vector</b>.
- *  \param[in,out] Vector El vector a multiplicar.
+ *  \brief Multiplica al vector \b Vector por un escalar. <br><b>Vector=Val*Vector</b>.
+ *  \param[in,out] Vector Es el vector a multiplicar.
  *  \param[in] Val Es el valor que multiplicará a los elementos del vector.
  *  \return TRUE si todo fue bien o FALSE si no.
  *  \ingroup PdsVectorGroup
@@ -232,8 +238,9 @@ int pds_vector_mul_value(PdsVector *Vector,PdsRaReal Val);
 
 
 /** \fn int pds_vector_div_value(PdsVector *Vector,PdsRaReal Val)
- *  \brief Divide al vector de tipo puntero PdsVector por un escalar. <br><b>Vector=Vector/Val</b>.
- *  \param[in,out] Vector El vector a dividir.
+ *  \brief Divide al vector \b Vector por un escalar. Carga el resultado en el
+ *  propio vector. <br><b>Vector=Vector/Val</b>.
+ *  \param[in,out] Vector Es el vector a dividir.
  *  \param[in] Val Es el valor que dividirá a los elementos del vector.
  *  \return TRUE si todo fue bien o FALSE si no.
  *  \ingroup PdsVectorGroup
@@ -242,11 +249,12 @@ int pds_vector_div_value(PdsVector *Vector,PdsRaReal Val);
 
 
 /** \fn int pds_vector_dot_vector(const PdsVector *Vector1,const PdsVector *Vector2,PdsRaReal *Val)
- *  \brief Ejecuta el producto punto en el vector Vector1 y Vector2, y lo carga en Val.
+ *  \brief Ejecuta el producto punto entre el \b Vector1 y el \b Vector2.
+ *  El resultado es cargado en \b Val.
  *  Los tamaños deben ser iguales. <br><b>Val=(Vector1,Vector2) </b>.
  *  \param[in] Vector1 Es el vector operando.
  *  \param[in] Vector2 Es el Vector operando.
- *  \param[out] Val El producto punto entre Vector1 y Vector2.
+ *  \param[out] Val El producto punto entre \b Vector1 y \b Vector2.
  *  \return TRUE si todo fue bien o FALSE si no.
  *  \ingroup PdsVectorGroup
  */
@@ -263,9 +271,17 @@ int pds_vector_printf(const PdsVector *Vector);
 
 
 /** \fn int pds_vector_fprintf(const PdsVector *Vector,FILE *fd)
- *  \brief Imprime en el archivo que apunta fd un vector de tipo puntero PdsVector.
- *  \param[in] Vector El vector a imprimir en pantalla.
- *  \param[in,out] fd El puntero al archivo.
+ *  \brief Imprime en el archivo al que apunta \b fd el contenido de un vector \b Vector.
+ *  \b fd es un manejador de archivo a un archivo de texto.
+ *  Para usar:
+\code{.h}
+FILE *fd=NULL;
+fd=fopen ("file.txt", "w+");
+pds_vector_fprintf(Vector,fd);
+fclose(fd);
+\endcode
+ *  \param[in] Vector El vector a imprimir en el archivo de texto.
+ *  \param[in,out] fd Un manejador de archivo de texto.
  *  \return TRUE si todo fue bien o FALSE si no.
  *  \ingroup PdsVectorGroup
  */
@@ -273,10 +289,18 @@ int pds_vector_fprintf(const PdsVector *Vector,FILE *fd);
 
 
 /** \fn int pds_vector_fscanf(PdsVector *Vector, FILE *fd)
- *  \brief Inicializa un vector con los datos del archivo apuntado por fd.
+ *  \brief Inicializa un vector \b Vector con los datos del archivo de texto apuntado por \b fd.
+ *  Si la cantidad de elementos no es suficiente, entonces el vector es completado con ceros.
  *  Usa TAB o un salto de linea como delimitador de elemento.
- *  \param[in] Vector Vector en donde se cargaran los datos.
- *  \param[in] fd Apuntador del archivo de donde se cargará los datos iniciales
+ *  Para usar:
+\code{.h}
+FILE *fd=NULL;
+fd=fopen ("file.txt", "r");
+pds_vector_fscanf(Vector,fd);
+fclose(fd);
+\endcode
+ *  \param[in] Vector Vector en donde se cargarán los datos.
+ *  \param[in] fd Apuntador del archivo de donde se cargarán los datos iniciales
  *  del vector.
  *  \return TRUE si todo fue bien o FALSE si no. (ej. Vector==NULL o fd==NULL)
  *  \ingroup PdsVectorGroup
@@ -285,10 +309,16 @@ int pds_vector_fscanf(PdsVector *Vector, FILE *fd);
 
 
 /** \fn int pds_vector_fwrite(PdsVector *Vector, FILE *fd)
- *  \brief Escribe los datos de un vector en el archivo binario apuntado por fd.
- *  \param[in] Vector Vector de donde se leeran los datos.
- *  \param[in] fd Apuntador del archivo binario de donde se escribiran los datos 
- *  del vector.
+ *  \brief Escribe los datos de un vector en el archivo binario apuntado por \b fd.
+ *  Para usar:
+\code{.h}
+FILE *fd=NULL;
+fd=fopen ("file.dat", "wb");
+pds_vector_fwrite(Vector, fd);
+fclose(fd);
+\endcode
+ *  \param[in] Vector Vector de donde se leerán los datos.
+ *  \param[in] fd Apuntador del archivo binario de donde se escribirán los datos.
  *  \return TRUE si todo fue bien o FALSE si no. (ej. Vector==NULL o fd==NULL)
  *  \ingroup PdsVectorGroup
  */
@@ -296,9 +326,18 @@ int pds_vector_fwrite(PdsVector *Vector, FILE *fd);
 
 
 /** \fn int pds_vector_fread(PdsVector *Vector, FILE *fd)
- *  \brief Inicializa un vector con los datos del archivo binario apuntado por fd.
+ *  \brief Inicializa un vector \b Vector con los datos del archivo binario apuntado por \b fd.
+ *  Si la cantidad de datos en el archivo es menor a la cantidad de elementos 
+ *  del vector \b Vector, entonces se completa con ceros.
+ *  Para usar:
+\code{.h}
+FILE *fd=NULL;
+fd=fopen ("file.dat", "rb");
+pds_vector_fread(Vector, fd);
+fclose(fd);
+\endcode
  *  \param[in] Vector Vector en donde se cargaran los datos.
- *  \param[in] fd Apuntador del archivo binario de donde se cargará los datos 
+ *  \param[in] fd Apuntador del archivo binario de donde se cargarán los datos 
  *  iniciales del vector.
  *  \return TRUE si todo fue bien o FALSE si no. (ej. Vector==NULL o fd==NULL)
  *  \ingroup PdsVectorGroup
@@ -389,15 +428,31 @@ int pds_vector_mean_vector(const PdsVector *Vector, PdsRaReal *m);
 int pds_vector_var_vector(const PdsVector *Vector, PdsRaReal *v);
 
 
-/** \fn int pds_vector_cov_vector (const PdsVector *VectorX,const PdsVector *VectorY, PdsRaReal *c)
- *  \brief Devuelve el valor de la covarianza muestral de los vectores VectorX y VectorY.
+/** \fn int pds_vector_var_vector(const PdsVector *Vector, PdsRaReal *v)
+ *  \brief Devuelve el valor del desvio padron \f$\sigma\f$ del vector Vector (X).
  *
+ *  \f[ \eta=\frac{\sum_{i=0}^{Nel-1} {X_i}}{Nel} \f]
+ *  \f[ \sigma^2=\frac{\sum_{i=0}^{Nel-1} {(X_i-\eta)^2}}{Nel} \f]
+ *  \param[in] Vector El vector en consulta.
+ *  \param[out] v El valor de desvio padron del vector Vector.
+ *  \return TRUE si todo fue bien o FALSE si no (ej: Vector==NULL). 
+ *  \ingroup PdsVectorGroup
+ */
+int pds_vector_std_vector(const PdsVector *Vector, PdsRaReal *v);
+
+
+/** \fn int pds_vector_cov_vector (const PdsVector *VectorX,const PdsVector *VectorY, PdsRaReal *c)
+ *  \brief Devuelve el valor de la covarianza muestral de los vectores \b VectorX y \b VectorY.
+ *
+ *  \f[ cov(X,Y)=\frac{\sum_{i=0}^{Nel-1} {(X_i -{\eta}_x)(Y_i -{\eta}_y)}}{Nel-1} \f]
+ *
+ *  Siendo \f$\eta_x\f$ y \f$\eta_y\f$:
  *  \f[ \eta_x=\frac{\sum_{i=0}^{Nel-1} {X_i}}{Nel} \f]
  *  \f[ \eta_y=\frac{\sum_{i=0}^{Nel-1} {Y_i}}{Nel} \f]
- *  \f[ cov(X,Y)=\frac{\sum_{i=0}^{Nel-1} {(X_i -{\eta}_x)(Y_i -{\eta}_y)}}{Nel-1} \f]
+ *
  *  \param[in] VectorX El vector en consulta.
  *  \param[in] VectorY El vector en consulta.
- *  \param[out] c El valor de la covarianza de los vectores VectorX y VectorY.
+ *  \param[out] c El valor de la covarianza de los vectores \b VectorX y \b VectorY.
  *  \return TRUE si todo fue bien o FALSE si no (ej: VectorX==NULL, VectorY==NULL o
  *  longitudes distintas). 
  *  \ingroup PdsVectorGroup
@@ -406,14 +461,17 @@ int pds_vector_cov_vector (const PdsVector *VectorX,const PdsVector *VectorY, Pd
 
 
 /** \fn int pds_vector_cor_vector (const PdsVector *VectorX,const PdsVector *VectorY, PdsRaReal *c)
- *  \brief Devuelve el valor del coeficiente de correlación muestral de los vectores VectorX y VectorY.
+ *  \brief Devuelve el valor del coeficiente de correlación de los vectores \b VectorX y \b VectorY.
  *
+ *  \f[ cor(X,Y)=\frac{\sum_{i=0}^{Nel-1} {(X_i -{\eta}_x)(Y_i -{\eta}_y)}}{\sqrt{\sum_{i=0}^{Nel-1} {(X_i -{\eta}_x)^2}}\sqrt{\sum_{i=0}^{Nel-1} {(Y_i -{\eta}_y)^2}}} \f]
+ *
+ *  Siendo \f$\eta_x\f$ y \f$\eta_y\f$:
  *  \f[ \eta_x=\frac{\sum_{i=0}^{Nel-1} {X_i}}{Nel} \f]
  *  \f[ \eta_y=\frac{\sum_{i=0}^{Nel-1} {Y_i}}{Nel} \f]
- *  \f[ cor(X,Y)=\frac{\sum_{i=0}^{Nel-1} {(X_i -{\eta}_x)(Y_i -{\eta}_y)}}{\sqrt{\sum_{i=0}^{Nel-1} {(X_i -{\eta}_x)^2}}\sqrt{\sum_{i=0}^{Nel-1} {(Y_i -{\eta}_y)^2}}} \f]
+ *
  *  \param[in] VectorX El vector en consulta.
  *  \param[in] VectorY El vector en consulta.
- *  \param[out] c El valor de la correlación de los vectores VectorX y VectorY.
+ *  \param[out] c El valor de la correlación de los vectores \b VectorX y \b VectorY.
  *  \return TRUE si todo fue bien o FALSE si no (ej: VectorX==NULL, VectorY==NULL o
  *  longitudes distintas). 
  *  \ingroup PdsVectorGroup
@@ -421,6 +479,21 @@ int pds_vector_cov_vector (const PdsVector *VectorX,const PdsVector *VectorY, Pd
 int pds_vector_cor_vector (const PdsVector *VectorX,const PdsVector *VectorY, PdsRaReal *c);
 
 
+/** \fn PdsVector* pds_vector_new_conv(const PdsVector *Vector1,const PdsVector *Vector2)
+ *  \brief Devuelve un nuevo vector con la convolución de Vector1 y Vector2 de
+ *  longitudes N1 y N2 respectivamente.
+ *
+ *  \f[ C(m)=\sum_{i=0, \forall 0 \leq (m-i) \leq N2-1}^{N1-1} Vector1(i)*Vector2(m-i) \f]
+ *
+ *  \param[in] Vector1 Un vector a convolucionar.
+ *  \param[in] Vector2 Un vector a convolucionar.
+ *  \return Retorna un vector con la convolución de Vector1 e Vector2 o NULL en 
+ *  caso de error. 
+ *  \ingroup PdsVectorGroup
+ */
+PdsVector* pds_vector_new_conv(const PdsVector *Vector1,const PdsVector *Vector2);
+
+
 /** \fn int pds_vector_get_value(const PdsVector *Vector, PdsRaNatural x, PdsRaReal *m)
  *  \brief Devuelve el valor en la posición (x) del vector Vector.
  *  (x) inicia con (0).
@@ -532,7 +605,7 @@ int pds_vector_set_gray(PdsVector *Vector,PdsRaNatural n,PdsRaNatural b0,PdsRaNa
 
 
 /** \fn int pds_vector_cmp(const PdsVector *Vector1,const PdsVector *Vector2,PdsRaNatural *n)
- *  \brief Compara los vectores Vector1 y Vector2 y retorna la cantidad de elementos distintos.
+ *  \brief Compara los vectores \b Vector1 y \b Vector2, retorna  en \b n la cantidad de elementos distintos.
  *  \param[in] Vector1 Un vector a comparar.
  *  \param[in] Vector2 Un vector a comparar.
  *  \param[out] n EL número de elementos diferentes entre los vectores.
@@ -542,8 +615,51 @@ int pds_vector_set_gray(PdsVector *Vector,PdsRaNatural n,PdsRaNatural b0,PdsRaNa
 int pds_vector_cmp(const PdsVector *Vector1,const PdsVector *Vector2,PdsRaNatural *n);
 
 
+/** \fn PdsVector *pds_vector_new_linspace(PdsRaReal x1,PdsRaReal x2,PdsRaNatural N
+ *  \brief Crea un vector de tipo PdsVector e inicia sus valores con N elementos
+ *  equidistantemente espaciados ((x2-x1)/(N-1)) entre x1 y x2 (inclusive).
+ *  \param[in] N Es la longitud del vector.
+ *  \return Un puntero al vector de tipo PdsVector.
+ *  \ingroup PdsVectorGroup
+ */
+PdsVector *pds_vector_new_linspace(PdsRaReal x1,PdsRaReal x2,PdsRaNatural N);
+
+
+/** \fn PdsVector *pds_vector_new_rectangular(PdsRaNatural N)
+ *  \brief Crea un vector de tipo PdsVector e inicia sus valores con una ventana
+ *  rectangular W.
+ *  \f[ W[n]=1 ~~~ \forall 0 \leq n<N\f]
+ *  \param[in] N Es la longitud del vector que representa la ventana de rectangular.
+ *  \return Un puntero al vector de tipo PdsVector.
+ *  \ingroup PdsVectorGroup
+ */
+PdsVector *pds_vector_new_rectangular(PdsRaNatural N);
+
+
+/** \fn PdsVector *pds_vector_new_hamming(PdsRaNatural N)
+ *  \brief Crea un vector de tipo PdsVector e inicia sus valores con una ventana
+ *  de Hamming W.
+ *  \f[ W[n]=0.54-0.46 cos(2 \frac{\pi n}{N-1}) ~~~ \forall 0 \leq n<N\f]
+ *  \param[in] N Es la longitud del vector que representa la ventana de Hamming.
+ *  \return Un puntero al vector de tipo PdsVector.
+ *  \ingroup PdsVectorGroup
+ */
+PdsVector *pds_vector_new_hamming(PdsRaNatural N);
+
+
+/** \fn PdsVector *pds_vector_new_blackman(PdsRaNatural N,PdsRaReal Alpha)
+ *  \brief Crea un vector de tipo PdsVector e inicia sus valores con una ventana
+ *  de Blackman.
+ *  \f[ W[n]=\frac{1-Alpha}{2}-\frac{1}{2} cos(2 \frac{\pi n}{N-1}) +\frac{Alpha}{2} cos(4 \frac{\pi n}{N-1}) ~~~ \forall 0 \leq n<N\f]
+ *  \param[in] N Es la longitud del vector que representa la ventana de Blackman.
+ *  \return Un puntero al vector de tipo PdsVector.
+ *  \ingroup PdsVectorGroup
+ */
+PdsVector *pds_vector_new_blackman(PdsRaNatural N,PdsRaReal Alpha);
+
+
 /** \fn void pds_vector_free(PdsVector *Vector)
- *  \brief Libera un vector de tipo puntero PdsVector.
+ *  \brief Libera la memoria de un vector de tipo puntero PdsVector.
  *  \param[in,out] Vector El vector a liberar.
  *  \return No retorna valor.
  *  \ingroup PdsVectorGroup
@@ -552,8 +668,15 @@ void pds_vector_free(PdsVector *Vector);
 
 
 /** \fn void pds_vector_destroy(PdsVector **Vector)
- *  \brief Libera un vector de tipo puntero PdsVector, y limpia el puntero con NULL.
- *  \param[in,out] Vector El vector a liberar y limpiar.
+ *  \brief Teniendo un vector \b Vector de tipo <code>PdsVector *Vector</code>, entonces
+\code{.c}
+pds_vector_destroy(&Vector);
+\endcode
+ *  Libera la memoria usada por \b Vector y apunta \b Vector a NULL.
+ *  Apuntar Vector a NULL es una medida de seguridad para evitar
+ *  usar el vector después de liberado, así este no apuntará a un lugar que no le
+ *  corresponde mas.
+ *  \param[in,out] Vector Un puntero al vector a liberar y limpiar.
  *  \return No retorna valor.
  *  \ingroup PdsVectorGroup
  */
